#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef HAVE_GOBJECT
#undef HAVE_ODBC
#undef HAVE_MYSQL
#undef HAVE_INTERBASE
#undef HAVE_LDAP
#undef HAVE_MDB
#undef HAVE_ORACLE
#undef HAVE_PRIMEBASE
#undef HAVE_TDS
#undef HAVE_SYBASE
#undef SYBASE_DEBUG
#undef HAVE_POSTGRES
#undef HAVE_CAMEL

#undef HAVE_PERL
